@@ -23,11 +23,12 @@ def generate_noise(shape, noise_type='normal'):
 
     Returns:
     --------
-    - torch.FloatTensor
+    - torch.Tensor
         The generated noise with the specified size.
     """
     if noise_type == 'normal':
         return dist.Normal(0, 1).sample(shape)
     elif noise_type == 'uniform':
         return dist.Uniform(-1, 1).sample(shape)
-    raise ValueError(f'Invalid noise type {noise_type}.')
\ No newline at end of file
+    raise ValueError(f'Invalid noise type {noise_type}.')
+    
\ No newline at end of file
