@@ -6,5 +6,6 @@
 #  Copyright (c) 2019 Oliver Borchert. All rights reserved.
 #  
 
-from .model import Config, Configurable
-from .predictor import Predictor
+from .config import Config, Configurable
+from .estimator import Estimator
+from .data_parallel import DataParallel
