@@ -4,7 +4,7 @@
 #
 #  Created by Oliver Borchert on May 11, 2019.
 #  Copyright (c) 2019 Oliver Borchert. All rights reserved.
-#  
+#
 
 class cached_property:
     """
@@ -15,17 +15,12 @@ class cached_property:
     # MARK: Initialization
     def __init__(self, func):
         self.func = func
-        self._cache = None
+        self.__doc__ = func.__doc__
 
     # MARK: Special Methods
     def __get__(self, obj, objtype):
-        if self._cache is not None:
-            return self._cache
-        self._cache = self.func(obj)
-        return self._cache
-
-    def __repr__(self):
-        return self.func.__doc__
+        value = obj.__dict__[self.func.__name__] = self.func(obj)
+        return value
 
 
 def flatten(l):
